EXPORTS
	??0CCCAppViewPluginAknContainer@@QAE@XZ @ 1 NONAME ; CCCAppViewPluginAknContainer::CCCAppViewPluginAknContainer(void)
	??0CCCAppViewPluginAknView@@QAE@XZ @ 2 NONAME ; CCCAppViewPluginAknView::CCCAppViewPluginAknView(void)
	??1CCCAppViewPluginAknContainer@@UAE@XZ @ 3 NONAME ; CCCAppViewPluginAknContainer::~CCCAppViewPluginAknContainer(void)
	??1CCCAppViewPluginAknView@@UAE@XZ @ 4 NONAME ; CCCAppViewPluginAknView::~CCCAppViewPluginAknView(void)
	?AddObserverL@CCCAppCmsContactFetcherWrapper@@QAEXAAVMCCAppContactFieldDataObserver@@@Z @ 5 NONAME ; void CCCAppCmsContactFetcherWrapper::AddObserverL(class MCCAppContactFieldDataObserver &)
	?ContactFieldDataArray@CCCAppCmsContactFetcherWrapper@@QAEAAV?$RPointerArray@VCCmsContactField@@@@XZ @ 6 NONAME ; class RPointerArray<class CCmsContactField> & CCCAppCmsContactFetcherWrapper::ContactFieldDataArray(void)
	?ContactIdentifierLC@CCCAppCmsContactFetcherWrapper@@QAEPAVHBufC8@@XZ @ 7 NONAME ; class HBufC8 * CCCAppCmsContactFetcherWrapper::ContactIdentifierLC(void)
	?ContactInfo@CCCAppCmsContactFetcherWrapper@@QAEPBVCCmsContactFieldInfo@@XZ @ 8 NONAME ; class CCmsContactFieldInfo const * CCCAppCmsContactFetcherWrapper::ContactInfo(void)
	?ContactStore@CCCAppCmsContactFetcherWrapper@@QBE?AW4TCmsContactStore@@XZ @ 9 NONAME ; enum TCmsContactStore CCCAppCmsContactFetcherWrapper::ContactStore(void) const
	?CreateInstanceL@CCCAppCmsContactFetcherWrapper@@SAPAV1@PAVCCCAParameter@@W4TWrapperParam@1@@Z @ 10 NONAME ; class CCCAppCmsContactFetcherWrapper * CCCAppCmsContactFetcherWrapper::CreateInstanceL(class CCCAParameter *, enum CCCAppCmsContactFetcherWrapper::TWrapperParam)
	?DoActivateL@CCCAppViewPluginAknView@@MAEXABVTVwsViewId@@VTUid@@ABVTDesC8@@@Z @ 11 NONAME ; void CCCAppViewPluginAknView::DoActivateL(class TVwsViewId const &, class TUid, class TDesC8 const &)
	?DoDeactivate@CCCAppViewPluginAknView@@MAEXXZ @ 12 NONAME ; void CCCAppViewPluginAknView::DoDeactivate(void)
	?GetContactActionFieldCount@CCCAppCmsContactFetcherWrapper@@QAEHW4TVPbkContactActionTypeSelector@VPbkFieldTypeSelectorFactory@@@Z @ 13 NONAME ; int CCCAppCmsContactFetcherWrapper::GetContactActionFieldCount(enum VPbkFieldTypeSelectorFactory::TVPbkContactActionTypeSelector)
	?HandleCommandL@CCCAppViewPluginAknView@@MAEXH@Z @ 14 NONAME ; void CCCAppViewPluginAknView::HandleCommandL(int)
	?HandleResourceChange@CCCAppViewPluginAknContainer@@MAEXH@Z @ 15 NONAME ; void CCCAppViewPluginAknContainer::HandleResourceChange(int)
	?InstanceL@CCCAppCmsContactFetcherWrapper@@SAPAV1@XZ @ 16 NONAME ; class CCCAppCmsContactFetcherWrapper * CCCAppCmsContactFetcherWrapper::InstanceL(void)
	?IsServiceAvailable@CCCAppCmsContactFetcherWrapper@@QAEHW4TVPbkContactActionTypeSelector@VPbkFieldTypeSelectorFactory@@@Z @ 17 NONAME ; int CCCAppCmsContactFetcherWrapper::IsServiceAvailable(enum VPbkFieldTypeSelectorFactory::TVPbkContactActionTypeSelector)
	?OfferKeyEventL@CCCAppViewPluginAknContainer@@MAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 18 NONAME ; enum TKeyResponse CCCAppViewPluginAknContainer::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?Release@CCCAppCmsContactFetcherWrapper@@QAEXXZ @ 19 NONAME ; void CCCAppCmsContactFetcherWrapper::Release(void)
	?RemoveObserver@CCCAppCmsContactFetcherWrapper@@QAEXAAVMCCAppContactFieldDataObserver@@@Z @ 20 NONAME ; void CCCAppCmsContactFetcherWrapper::RemoveObserver(class MCCAppContactFieldDataObserver &)
	?SetTitleL@CCCAppViewPluginAknView@@QAEXABVTDesC16@@@Z @ 21 NONAME ; void CCCAppViewPluginAknView::SetTitleL(class TDesC16 const &)		
	?NewL@CCCAppStatusControl@@SAPAV1@AAVCSpbContentProvider@@AAVMCCAStatusControlObserver@@@Z @ 22 NONAME ; class CCCAppStatusControl * CCCAppStatusControl::NewL(class CSpbContentProvider &, class MCCAStatusControlObserver &)
	?SetContactLinkL@CCCAppStatusControl@@QAEXAAVMVPbkContactLink@@@Z @ 23 NONAME ; void CCCAppStatusControl::SetContactLinkL(class MVPbkContactLink &)	
	?NewL@CCCaFactoryExtensionNotifier@@SAPAV1@XZ @ 24 NONAME ; class CCCaFactoryExtensionNotifier * CCCaFactoryExtensionNotifier::NewL(void)
	?ObserveExtensionFactoryL@CCCaFactoryExtensionNotifier@@QAEXAAVTCallBack@@@Z @ 25 NONAME ; void CCCaFactoryExtensionNotifier::ObserveExtensionFactory(class TCallBack &)
	?ExtensionFactory@CCCaFactoryExtensionNotifier@@QAEPAVCCCAExtensionFactory@@XZ @ 26 NONAME ; class CCCAExtensionFactory * CCCaFactoryExtensionNotifier::ExtensionFactory(void)
	?StartL@CCCAppImageDecoding@@QAEXABVTSize@@@Z @ 27 NONAME ; void CCCAppImageDecoding::StartL(class TSize const &)
	?NewL@CCCAppImageDecoding@@SAPAV1@AAVMCCAppImageDecodingObserver@@AAVRFs@@PAVHBufC8@@PAVHBufC16@@@Z @ 28 NONAME ; class CCCAppImageDecoding * CCCAppImageDecoding::NewL(class MCCAppImageDecodingObserver &, class RFs &, class HBufC8 *, class HBufC16 *)
	?SetDefaultStatusTextL@CCCAppStatusControl@@QAEXPAVHBufC16@@@Z @ 29 NONAME ; void CCCAppStatusControl::SetDefaultStatusTextL(class HBufC16 *)
	?SetDefaultStatusIconL@CCCAppStatusControl@@QAEXPAVCGulIcon@@@Z @ 30 NONAME ; void CCCAppStatusControl::SetDefaultStatusIcon(class CGulIcon *)
	?IsTopContact@CCCAppCmsContactFetcherWrapper@@QAEHXZ @ 31 NONAME ; int CCCAppCmsContactFetcherWrapper::IsTopContact(void)
